@@ -1,6 +1,6 @@
 ################################################################################
 #
-# Copyright 2021-2022 Rocco Matano
+# Copyright 2021-2023 Rocco Matano
 #
 # Permission is hereby granted, free of charge, to any person obtaining a
 # copy of this software and associated documentation files (the "Software"),
@@ -278,8 +278,7 @@ def enum_processes():
     def _name_pid(pi):
         pid = pi.UniqueProcessId if pi.UniqueProcessId else 0
         name = (
-            ctypes.wstring_at(pi.ImageName.Buffer, pi.ImageName.Length // 2)
-            if pi.ImageName.Buffer else
+            str(pi.ImageName) if pi.ImageName.Buffer else
             ("idle" if pid == 0 else "system")
             )
         return _namespace(name=name, pid=pid)
@@ -301,8 +300,7 @@ def enum_processes():
     res.append(_name_pid(pi))
 
     while True:
-        offs = pi.NextEntryOffset
-        if offs == 0:
+        if (offs := pi.NextEntryOffset) == 0:
             break
         pi = SYSTEM_PROCESS_INFORMATION.from_address(
             ctypes.addressof(pi) + offs
@@ -360,7 +358,7 @@ def proc_path_from_pid(pid):
         spii.ImageName.Buffer = ctypes.addressof(buf)
 
     raise_failed_status(status)
-    return _resolve_device_prefix(buf.value)
+    return _resolve_device_prefix(str(spii.ImageName))
 
 ################################################################################
 
@@ -368,12 +366,11 @@ def proc_path_from_handle(handle):
     info = ProcessImageFileName
     rlen = required_proc_info_size(handle, info)
     buf = ctypes.create_string_buffer(rlen.value)
+    addr = ctypes.addressof(buf)
     raise_failed_status(
-        NtQueryInformationProcess(handle, info, ref(buf), rlen, ref(rlen))
-        )
-    return _resolve_device_prefix(
-        ctypes.wstring_at(ctypes.addressof(buf) + ctypes.sizeof(UNICODE_STRING))
+        NtQueryInformationProcess(handle, info, addr, rlen, ref(rlen))
         )
+    return _resolve_device_prefix(str(UNICODE_STRING.from_address(addr)))
 
 ################################################################################
 
