@@ -1,6 +1,6 @@
 ################################################################################
 #
-# Copyright 2021-2022 Rocco Matano
+# Copyright 2021-2023 Rocco Matano
 #
 # Permission is hereby granted, free of charge, to any person obtaining a
 # copy of this software and associated documentation files (the "Software"),
@@ -99,6 +99,12 @@ class GUID(ULONG * 4):         # using ULONG for correct alignment
     def __repr__(self):
         return f"{self.__class__.__name__}('{self.uuid()!s}')"
 
+    def __eq__(self, other):
+        try:
+            return bytes(self) == bytes(other)
+        except Exception:
+            return False
+
 ################################################################################
 
 class FILETIME(ctypes.Structure):
@@ -250,6 +256,12 @@ class UNICODE_STRING(ctypes.Structure):
         ("Buffer", ctypes.c_wchar_p),
         )
 
+    def __str__(self):
+        return ctypes.wstring_at(
+            self.Buffer,
+            self.Length // ctypes.sizeof(WCHAR)
+            )
+
 ################################################################################
 
 class LUID(ctypes.Structure):
